"use client";
import Box from "@/components/Box";
import Footer from "@/components/Footer";
import Header from "@/components/Header";
import Sidebar from "@/components/Layout/Sidebar";
import styles from "@/components/Layout/style.module.scss";
import { FC, PropsWithChildren, ReactNode, useRef } from "react";
import { Swiper, SwiperClass, SwiperSlide } from "swiper/react";
type Props = {
    swiperWidget: ReactNode;
    popupWidget: ReactNode;
    cardWidget: ReactNode;
    noticeWidget: ReactNode;
    searchWidget: ReactNode;
    prizeWidget: ReactNode;
};
const Layout: FC<PropsWithChildren<Props>> = (props) => {
    const {
        children,
        swiperWidget,
        popupWidget,
        cardWidget,
        noticeWidget,
        searchWidget,
        prizeWidget,
        ...other
    } = props;
    const swiperRef = useRef<SwiperClass>();
    const isOpen = useRef<boolean>(false);
    const homeContainerRef = useRef<HTMLDivElement>(null);
    const barRef = useRef<HTMLDivElement>(null);

    const startHandler = () => {
        homeContainerRef.current?.classList.add(styles.containerMask);
        barRef.current?.classList.add(styles.cross);
        isOpen.current = true;
    };
    const endHandler = () => {
        homeContainerRef.current?.classList.remove(styles.containerMask);
        barRef.current?.classList.remove(styles.cross);
        isOpen.current = false;
    };

    const openSliderHandler = () => {
        if (isOpen.current) {
            swiperRef.current?.slideNext();
        } else {
            swiperRef.current?.slidePrev();
        }
    };

    return (
        <>
            <Swiper
                resistanceRatio={10}
                initialSlide={1}
                slidesPerView={"auto"}
                onSlidePrevTransitionStart={startHandler}
                onSlideNextTransitionEnd={endHandler}
                slideToClickedSlide
                onSwiper={(swiper) => {
                    swiperRef.current = swiper;
                    // 设置第一个元素
                    swiper.slides[0].style.display = "block";
                }}
                runCallbacksOnInit={false}
                allowTouchMove={false}
            >
                <SwiperSlide
                    style={{ width: `${"70%"}`, display: "none" }}
                    className={"bg-[rgb(31,31,31)]"}
                >
                    <section className="relative h-[100vh]">
                        <Sidebar></Sidebar>
                    </section>
                </SwiperSlide>

                <SwiperSlide style={{ width: "100%" }}>
                    <section className="relative h-[100%]" ref={homeContainerRef}>
                        <Header
                            {...other}
                            menuRender={() => (
                                <div
                                    className={`absolute left-[0.1rem] top-[0.03rem] z-40 text-[#fff]`}
                                    ref={barRef}
                                    onClick={openSliderHandler}
                                >
                                    <div className={styles.bar}></div>
                                    <div
                                        className={styles.bar}
                                        style={{ width: "0.1389rem" }}
                                    ></div>
                                    <div className={styles.bar}></div>
                                </div>
                            )}
                        ></Header>
                        <main id="maincontainer" className={"main-footer-header"}>
                            {popupWidget}
                            <Box>
                                {swiperWidget}
                                {cardWidget}
                                {noticeWidget}
                                {searchWidget}
                                {prizeWidget}
                            </Box>
                            {children}
                        </main>
                        <Footer></Footer>
                    </section>
                </SwiperSlide>
            </Swiper>
        </>
    );
};

export default Layout;
